@@ -19,6 +19,10 @@
 
 from os import getenv, path
 
+import cyclonedx
+
+CDX_SCHEMA_DIRECTORY = path.join(path.dirname(cyclonedx.__file__), 'schema')
+
 FIXTURES_DIRECTORY = path.join(path.dirname(__file__), 'fixtures')
 
 RECREATE_SNAPSHOTS = bool(getenv('CDX_TEST_RECREATE_SNAPSHOTS'))
